
function [ y ] = problem(x)

% fitness_mli: This function calculates the minimum values of fitness function for SHE problem.
% input arguments : alpha matrix same as par matrix where angle are in radian. 
% output argument : cost vector of fitness function for par matrix.  

%% Initialize costants and input variables

Vdc = 12; % magnitude of voltage source in volt 
Ma = 0.8; % Value of desired modulation index(control parameter for desired fundamental voltage)
s=5;

% Desired and actual magnitude of fundamental voltage.

V1_desired = (Ma*4*s*Vdc)/pi;
V1_actual  = (4*Vdc/pi)*(cos(x(:,1))+cos(x(:,2))+cos(x(:,3))+cos(x(:,4))+cos(x(:,5)));

% Low order harmonic voltages.

V5 = ((4*Vdc)/(5*pi))*(cos(5*x(:,1))+cos(5*x(:,2))+cos(5*x(:,3))+cos(5*x(:,4))+cos(5*x(:,5)));
V7 = ((4*Vdc)/(7*pi))*(cos(7*x(:,1))+cos(7*x(:,2))+cos(7*x(:,3))+cos(7*x(:,4))+cos(7*x(:,5)));
V11 = ((4*Vdc)/(11*pi))*(cos(11*x(:,1))+cos(11*x(:,2))+cos(11*x(:,3))+cos(11*x(:,4))+cos(11*x(:,5)));
V13 = ((4*Vdc)/(13*pi))*(cos(13*x(:,1))+cos(13*x(:,2))+cos(13*x(:,3))+cos(13*x(:,4))+cos(13*x(:,5)));
% fitness function to be minimized.

y = ((100*(V1_desired-V1_actual)./V1_desired)).^4 + (1/5)*(50*(V5./V1_actual)).^2 + (1/7)*(50*(V7./V1_actual)).^2 + (1/11)*(50*(V11./V1_actual)).^2+ (1/13)*(50*(V13./V1_actual)).^2;

end




